==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_entities/materiallistpart_001/MaterialListPart.java <==

package net.datastream.schemas.mp_entities.materiallistpart_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.MANUFACTURERID_Type;
import net.datastream.schemas.mp_fields.MATERIALLISTPARTID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.UOMID_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MATERIALLISTPARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTQUANTITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CRITICAL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RESERVEPART" minOccurs="0"/>
 *         &lt;element name="DIRECT" type="{http://schemas.datastream.net/MP_fields}FLAG_Type"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRIMARYMANUFACTURERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRIMARYMANUFACTURERPARTCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTTYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTCONDITIONTEMPLATECONDITIONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LONGDESCRIPTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISOPTIONAL" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "materiallistpartid",
    "partid",
    "partquantity",
    "equipmentid",
    "uomid",
    "critical",
    "reservepart",
    "direct",
    "primarymanufacturerid",
    "primarymanufacturerpartcode",
    "equipmenttype",
    "partconditiontemplateconditioncode",
    "longdescription",
    "isoptional"
})
@XmlRootElement(name = "MaterialListPart")
public class MaterialListPart {

    @XmlElement(name = "MATERIALLISTPARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected MATERIALLISTPARTID_Type materiallistpartid;
    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "PARTQUANTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY partquantity;
    @XmlElement(name = "EQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "UOMID", namespace = "http://schemas.datastream.net/MP_fields")
    protected UOMID_Type uomid;
    @XmlElement(name = "CRITICAL", namespace = "http://schemas.datastream.net/MP_fields")
    protected String critical;
    @XmlElement(name = "RESERVEPART", namespace = "http://schemas.datastream.net/MP_fields")
    protected String reservepart;
    @XmlElement(name = "DIRECT", required = true, defaultValue = "-")
    protected String direct;
    @XmlElement(name = "PRIMARYMANUFACTURERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected MANUFACTURERID_Type primarymanufacturerid;
    @XmlElement(name = "PRIMARYMANUFACTURERPARTCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String primarymanufacturerpartcode;
    @XmlElement(name = "EQUIPMENTTYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String equipmenttype;
    @XmlElement(name = "PARTCONDITIONTEMPLATECONDITIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partconditiontemplateconditioncode;
    @XmlElement(name = "LONGDESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String longdescription;
    @XmlElement(name = "ISOPTIONAL", namespace = "http://schemas.datastream.net/MP_fields")
    protected String isoptional;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the materiallistpartid property.
     * 
     * @return
     *     possible object is
     *     {@link MATERIALLISTPARTID_Type }
     *     
     */
    public MATERIALLISTPARTID_Type getMATERIALLISTPARTID() {
        return materiallistpartid;
    }

    /**
     * Sets the value of the materiallistpartid property.
     * 
     * @param value
     *     allowed object is
     *     {@link MATERIALLISTPARTID_Type }
     *     
     */
    public void setMATERIALLISTPARTID(MATERIALLISTPARTID_Type value) {
        this.materiallistpartid = value;
    }

    /**
     * Gets the value of the partid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Sets the value of the partid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Gets the value of the partquantity property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPARTQUANTITY() {
        return partquantity;
    }

    /**
     * Sets the value of the partquantity property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPARTQUANTITY(QUANTITY value) {
        this.partquantity = value;
    }

    /**
     * Gets the value of the equipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Sets the value of the equipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Gets the value of the uomid property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Sets the value of the uomid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

    /**
     * Gets the value of the critical property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCRITICAL() {
        return critical;
    }

    /**
     * Sets the value of the critical property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCRITICAL(String value) {
        this.critical = value;
    }

    /**
     * Gets the value of the reservepart property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRESERVEPART() {
        return reservepart;
    }

    /**
     * Sets the value of the reservepart property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRESERVEPART(String value) {
        this.reservepart = value;
    }

    /**
     * Gets the value of the direct property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDIRECT() {
        return direct;
    }

    /**
     * Sets the value of the direct property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDIRECT(String value) {
        this.direct = value;
    }

    /**
     * Gets the value of the primarymanufacturerid property.
     * 
     * @return
     *     possible object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public MANUFACTURERID_Type getPRIMARYMANUFACTURERID() {
        return primarymanufacturerid;
    }

    /**
     * Sets the value of the primarymanufacturerid property.
     * 
     * @param value
     *     allowed object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public void setPRIMARYMANUFACTURERID(MANUFACTURERID_Type value) {
        this.primarymanufacturerid = value;
    }

    /**
     * Gets the value of the primarymanufacturerpartcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRIMARYMANUFACTURERPARTCODE() {
        return primarymanufacturerpartcode;
    }

    /**
     * Sets the value of the primarymanufacturerpartcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRIMARYMANUFACTURERPARTCODE(String value) {
        this.primarymanufacturerpartcode = value;
    }

    /**
     * Gets the value of the equipmenttype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQUIPMENTTYPE() {
        return equipmenttype;
    }

    /**
     * Sets the value of the equipmenttype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEQUIPMENTTYPE(String value) {
        this.equipmenttype = value;
    }

    /**
     * Gets the value of the partconditiontemplateconditioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTCONDITIONTEMPLATECONDITIONCODE() {
        return partconditiontemplateconditioncode;
    }

    /**
     * Sets the value of the partconditiontemplateconditioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTCONDITIONTEMPLATECONDITIONCODE(String value) {
        this.partconditiontemplateconditioncode = value;
    }

    /**
     * Gets the value of the longdescription property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLONGDESCRIPTION() {
        return longdescription;
    }

    /**
     * Sets the value of the longdescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLONGDESCRIPTION(String value) {
        this.longdescription = value;
    }

    /**
     * Gets the value of the isoptional property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISOPTIONAL() {
        return isoptional;
    }

    /**
     * Sets the value of the isoptional property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISOPTIONAL(String value) {
        this.isoptional = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_entities/materiallistpart_001/MaterialListPart.java <==

package net.datastream.schemas.mp_entities.materiallistpart_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.MANUFACTURERID_Type;
import net.datastream.schemas.mp_fields.MATERIALLISTPARTID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.UOMID_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MATERIALLISTPARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTQUANTITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CRITICAL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RESERVEPART" minOccurs="0"/>
 *         &lt;element name="DIRECT" type="{http://schemas.datastream.net/MP_fields}FLAG_Type"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRIMARYMANUFACTURERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRIMARYMANUFACTURERPARTCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTTYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTCONDITIONTEMPLATECONDITIONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LONGDESCRIPTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISOPTIONAL" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "materiallistpartid",
    "partid",
    "partquantity",
    "equipmentid",
    "uomid",
    "critical",
    "reservepart",
    "direct",
    "primarymanufacturerid",
    "primarymanufacturerpartcode",
    "equipmenttype",
    "partconditiontemplateconditioncode",
    "longdescription",
    "isoptional"
})
@XmlRootElement(name = "MaterialListPart")
public class MaterialListPart {

    @XmlElement(name = "MATERIALLISTPARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected MATERIALLISTPARTID_Type materiallistpartid;
    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "PARTQUANTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY partquantity;
    @XmlElement(name = "EQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "UOMID", namespace = "http://schemas.datastream.net/MP_fields")
    protected UOMID_Type uomid;
    @XmlElement(name = "CRITICAL", namespace = "http://schemas.datastream.net/MP_fields")
    protected String critical;
    @XmlElement(name = "RESERVEPART", namespace = "http://schemas.datastream.net/MP_fields")
    protected String reservepart;
    @XmlElement(name = "DIRECT", required = true, defaultValue = "-")
    protected String direct;
    @XmlElement(name = "PRIMARYMANUFACTURERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected MANUFACTURERID_Type primarymanufacturerid;
    @XmlElement(name = "PRIMARYMANUFACTURERPARTCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String primarymanufacturerpartcode;
    @XmlElement(name = "EQUIPMENTTYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String equipmenttype;
    @XmlElement(name = "PARTCONDITIONTEMPLATECONDITIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partconditiontemplateconditioncode;
    @XmlElement(name = "LONGDESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String longdescription;
    @XmlElement(name = "ISOPTIONAL", namespace = "http://schemas.datastream.net/MP_fields")
    protected String isoptional;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété materiallistpartid.
     * 
     * @return
     *     possible object is
     *     {@link MATERIALLISTPARTID_Type }
     *     
     */
    public MATERIALLISTPARTID_Type getMATERIALLISTPARTID() {
        return materiallistpartid;
    }

    /**
     * Définit la valeur de la propriété materiallistpartid.
     * 
     * @param value
     *     allowed object is
     *     {@link MATERIALLISTPARTID_Type }
     *     
     */
    public void setMATERIALLISTPARTID(MATERIALLISTPARTID_Type value) {
        this.materiallistpartid = value;
    }

    /**
     * Obtient la valeur de la propriété partid.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Définit la valeur de la propriété partid.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Obtient la valeur de la propriété partquantity.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPARTQUANTITY() {
        return partquantity;
    }

    /**
     * Définit la valeur de la propriété partquantity.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPARTQUANTITY(QUANTITY value) {
        this.partquantity = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Définit la valeur de la propriété equipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Obtient la valeur de la propriété uomid.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Définit la valeur de la propriété uomid.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

    /**
     * Obtient la valeur de la propriété critical.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCRITICAL() {
        return critical;
    }

    /**
     * Définit la valeur de la propriété critical.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCRITICAL(String value) {
        this.critical = value;
    }

    /**
     * Obtient la valeur de la propriété reservepart.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRESERVEPART() {
        return reservepart;
    }

    /**
     * Définit la valeur de la propriété reservepart.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRESERVEPART(String value) {
        this.reservepart = value;
    }

    /**
     * Obtient la valeur de la propriété direct.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDIRECT() {
        return direct;
    }

    /**
     * Définit la valeur de la propriété direct.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDIRECT(String value) {
        this.direct = value;
    }

    /**
     * Obtient la valeur de la propriété primarymanufacturerid.
     * 
     * @return
     *     possible object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public MANUFACTURERID_Type getPRIMARYMANUFACTURERID() {
        return primarymanufacturerid;
    }

    /**
     * Définit la valeur de la propriété primarymanufacturerid.
     * 
     * @param value
     *     allowed object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public void setPRIMARYMANUFACTURERID(MANUFACTURERID_Type value) {
        this.primarymanufacturerid = value;
    }

    /**
     * Obtient la valeur de la propriété primarymanufacturerpartcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRIMARYMANUFACTURERPARTCODE() {
        return primarymanufacturerpartcode;
    }

    /**
     * Définit la valeur de la propriété primarymanufacturerpartcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRIMARYMANUFACTURERPARTCODE(String value) {
        this.primarymanufacturerpartcode = value;
    }

    /**
     * Obtient la valeur de la propriété equipmenttype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQUIPMENTTYPE() {
        return equipmenttype;
    }

    /**
     * Définit la valeur de la propriété equipmenttype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEQUIPMENTTYPE(String value) {
        this.equipmenttype = value;
    }

    /**
     * Obtient la valeur de la propriété partconditiontemplateconditioncode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTCONDITIONTEMPLATECONDITIONCODE() {
        return partconditiontemplateconditioncode;
    }

    /**
     * Définit la valeur de la propriété partconditiontemplateconditioncode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTCONDITIONTEMPLATECONDITIONCODE(String value) {
        this.partconditiontemplateconditioncode = value;
    }

    /**
     * Obtient la valeur de la propriété longdescription.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLONGDESCRIPTION() {
        return longdescription;
    }

    /**
     * Définit la valeur de la propriété longdescription.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLONGDESCRIPTION(String value) {
        this.longdescription = value;
    }

    /**
     * Obtient la valeur de la propriété isoptional.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISOPTIONAL() {
        return isoptional;
    }

    /**
     * Définit la valeur de la propriété isoptional.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISOPTIONAL(String value) {
        this.isoptional = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
